@@ -55,7 +55,7 @@
 #define MOD_GM_COMMON_H
 
 /* constants */
-#define GM_VERSION                 "4.0.3.20220823"
+#define GM_VERSION                 "4.0.4"
 #define GM_ENABLED                      1
 #define GM_DISABLED                     0
 #define GM_BUFFERSIZE               65536
@@ -90,6 +90,7 @@
 #define GM_LOG_MODE_CORE                3
 #define GM_LOG_MODE_SYSLOG              4
 #define GM_LOG_MODE_TOOLS               5
+#define GM_LOG_MODE_CHECKS              6
 
 /* job priorities */
 #define GM_JOB_PRIO_LOW                 1
