@@ -81,7 +81,7 @@ void worker_client(int worker_mode, int indx, int shid) {
     }
 
     /* create client */
-    if ( create_client( mod_gm_opt->server_list, &client ) != GM_OK ) {
+    if ( create_client_blocking( mod_gm_opt->server_list, &client ) != GM_OK ) {
         gm_log( GM_LOG_ERROR, "cannot start client\n" );
         clean_worker_exit(0);
         _exit( EXIT_FAILURE );
@@ -90,7 +90,7 @@ void worker_client(int worker_mode, int indx, int shid) {
 
     /* create duplicate client */
     if( mod_gm_opt->dupserver_num ) {
-        if ( create_client( mod_gm_opt->dupserver_list, &client_dup ) != GM_OK ) {
+        if ( create_client_blocking( mod_gm_opt->dupserver_list, &client_dup ) != GM_OK ) {
             gm_log( GM_LOG_ERROR, "cannot start client for duplicate server\n" );
             _exit( EXIT_FAILURE );
         }
@@ -121,7 +121,6 @@ void worker_loop() {
             alarm(mod_gm_opt->idle_timeout);
         }
 
-        signal(SIGPIPE, SIG_IGN);
         ret = gearman_worker_work( &worker );
 
         if (mod_gm_opt->max_jobs > 0 && jobs_done >= mod_gm_opt->max_jobs) {
@@ -145,10 +144,10 @@ void worker_loop() {
 
             /* create new connections */
             set_worker( &worker );
-            create_client( mod_gm_opt->server_list, &client );
+            create_client_blocking( mod_gm_opt->server_list, &client );
             current_client = &client;
             if( mod_gm_opt->dupserver_num ) {
-                create_client( mod_gm_opt->dupserver_list, &client_dup );
+                create_client_blocking( mod_gm_opt->dupserver_list, &client_dup );
                 current_client_dup = &client_dup;
             }
         }
@@ -159,7 +158,7 @@ void worker_loop() {
 
 
 /* get a job */
-void *get_job( gearman_job_st *job, void *context, size_t *result_size, gearman_return_t *ret_ptr ) {
+void *get_job( gearman_job_st *job, __attribute__((__unused__)) void *context, size_t *result_size, gearman_return_t *ret_ptr ) {
     sigset_t block_mask;
     int wsize, valid_lines;
     char * workload;
@@ -181,9 +180,6 @@ void *get_job( gearman_job_st *job, void *context, size_t *result_size, gearman_
 
     gm_log( GM_LOG_TRACE, "get_job()\n" );
 
-    /* contect is unused */
-    context = context;
-
     /* set size of result */
     *result_size = 0;
 
@@ -613,7 +609,7 @@ void clean_worker_exit(int sig) {
 
 
 /* answer status querys */
-void *return_status( gearman_job_st *job, void *context, size_t *result_size, gearman_return_t *ret_ptr ) {
+void *return_status( gearman_job_st *job, __attribute__((__unused__)) void *context, size_t *result_size, gearman_return_t *ret_ptr ) {
     int wsize;
     char workload[GM_BUFFERSIZE];
     int *shm;
@@ -621,9 +617,6 @@ void *return_status( gearman_job_st *job, void *context, size_t *result_size, ge
 
     gm_log( GM_LOG_TRACE, "return_status()\n" );
 
-    /* contect is unused */
-    context = context;
-
     /* get the data */
     wsize = gearman_job_workload_size(job);
     strncpy(workload, (const char*)gearman_job_workload(job), wsize);
@@ -671,11 +664,13 @@ void *return_status( gearman_job_st *job, void *context, size_t *result_size, ge
 void write_debug_file(char ** text) {
     FILE * fd;
     fd = fopen( "/tmp/mod_gearman_worker.txt", "a+" );
-    if(fd == NULL)
+    if(fd == NULL) {
         perror("fopen");
-    fputs( "------------->\n", fd );
-    fputs( *text, fd );
-    fputs( "\n<-------------\n", fd );
-    fclose( fd );
+    } else {
+        fputs( "------------->\n", fd );
+        fputs( *text, fd );
+        fputs( "\n<-------------\n", fd );
+        fclose( fd );
+    }
 }
 #endif
